import logging

from apistar import ASyncApp, App

from .service import Service
from .components import ServiceComponent, SettingsComponent
from .helper import load_packages, routing, print_routing

__all__ = ["Application"]

logger = logging.getLogger("star_builder.app")


def application(template_dir=None,
                static_dir=None,
                packages=None,
                schema_url='/schema/',
                docs_url='/docs/',
                static_url='/static/',
                components=None,
                event_hooks=None,
                settings_path="settings",
                debug=True,
                async=True):
    """
       参数指定选择使用异步app还是同步app
       可以动态发现当前项目根目录下所有routes的service中的handler
    """
    load_packages(".")
    include = routing(Service, None)
    SettingsComponent.register_path(settings_path)
    components = [ServiceComponent(), SettingsComponent()] + (components or [])

    if include:
        routes = [include]
        print_routing(routes, callback=logger.debug)
    else:
        logger.info("Noting to route. ")
        routes = []

    app = (ASyncApp if async else App)(
        routes,
        template_dir=template_dir,
        static_dir=static_dir,
        packages=packages,
        schema_url=schema_url,
        docs_url=docs_url,
        static_url=static_url,
        components=components,
        event_hooks=event_hooks)

    app.debug = debug
    return app


Application = application



# -*- coding:utf-8 -*-
import os
import re
try:
    from setuptools import setup, find_packages
except:
    from distutils.core import setup


def get_version(package):
    """
    Return package version as listed in `__version__` in `__init__.py`.
    """
    init_py = open(os.path.join(package, '__init__.py')).read()
    mth = re.search("__version__\s?=\s?['\"]([^'\"]+)['\"]", init_py)
    if mth:
        return mth.group(1)
    else:
        raise RuntimeError("Cannot find version!")


AUTHOR = "cn"

AUTHOR_EMAIL = "cnaafhvk@foxmail.com"

URL = "https://www.github.com/ShichaoMa/star_builder"

NAME = "star-builder"

DESCRIPTION = "enhance apistar web framework. "

try:
    LONG_DESCRIPTION = open("README.rst").read()
except UnicodeDecodeError:
    LONG_DESCRIPTION = open("README.rst", encoding="utf-8").read()

KEYWORDS = "apistar"

LICENSE = "MIT"

PACKAGES = ["star_builder"]

setup(
    name=NAME,
    version=get_version("star_builder"),
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
    ],
    keywords=KEYWORDS,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    entry_points={
        'console_scripts': [
            'apistar-create = star_builder:main',
        ],
    },
    license=LICENSE,
    packages=PACKAGES,
    install_requires=["apistar", "toolkity>=1.7.6"],
    include_package_data=True,
    zip_safe=True,
)